@@ -33,9 +33,6 @@
 #define DSNKEY_FPLIST_INDEX   26
 #define DSNKEY_STREAMRS_INDEX 43
 
-
-//extern "C" {
-
 /* If adding new connstring option, one should add them to the end of the array section before aliases, because some arrays defining program logic
    use indexes of an element in this array. In particular, in the setup lib there is array mapping dsn field(i.e. this array element) to parent window
    and resource id of the contorl in the dialog. Thus if you still think it should go somewhere in the middle, mind also change that array and at least
@@ -63,7 +60,10 @@ MADB_DsnKey DsnKeys[]=
   {"AUTO_RECONNECT", offsetof(MADB_Dsn, Reconnect),         DSN_TYPE_OPTION, MADB_OPT_FLAG_AUTO_RECONNECT,0},
   {"NO_PROMPT",      offsetof(MADB_Dsn, ConnectPrompt),     DSN_TYPE_OPTION, MADB_OPT_FLAG_NO_PROMPT,0},
   {"CHARSET",        offsetof(MADB_Dsn, CharacterSet),      DSN_TYPE_COMBO,  0, 0},
-  {"TRACE",          offsetof(MADB_Dsn, TraceFile),         DSN_TYPE_STRING, 0, 0},
+  /* TODO: this has to be removed.Changed to bool to take less memory : ) The problem is changed
+   * indexes of other elements of this array. I think they are relied upon in the setup dialog
+   */
+  {"TRACE",          offsetof(MADB_Dsn, TraceFile),         DSN_TYPE_BOOL, 0, 0},
   {"PLUGIN_DIR",     offsetof(MADB_Dsn, ConnCPluginsDir),   DSN_TYPE_STRING, 0, 0},
   /* SSL */
   {"SSLKEY",         offsetof(MADB_Dsn, SslKey),            DSN_TYPE_STRING, 0, 0},
@@ -95,7 +95,10 @@ MADB_DsnKey DsnKeys[]=
   {"EXECDSERVER",    offsetof(MADB_Dsn, EdPrepareOnServer), DSN_TYPE_BOOL,   0, 0},
   {"PREPONCLIENT",   offsetof(MADB_Dsn, PrepareOnClient),   DSN_TYPE_BOOL,   0, 0},
   {"PSCACHESIZE",    offsetof(MADB_Dsn, PsCacheSize),       DSN_TYPE_INT,    0, 0},
-  {"MAXCACHEKEY",    offsetof(MADB_Dsn, PsCacheMaxKeyLen),  DSN_TYPE_INT,    0, 0}, /* 48 */
+  {"MAXCACHEKEY",    offsetof(MADB_Dsn, PsCacheMaxKeyLen),  DSN_TYPE_INT,    0, 0},
+  {"PCALLBACK",      offsetof(MADB_Dsn, ParamCallbacks),    DSN_TYPE_BOOL,   0, 0},
+  {"RCALLBACK",      offsetof(MADB_Dsn, ResultCallbacks),   DSN_TYPE_BOOL,   0, 0}, /* 50 */
+  {"NOBIGINT",       offsetof(MADB_Dsn, NoBigint),          DSN_TYPE_OPTION, MADB_OPT_FLAG_NO_BIGINT, 0},
 
   /* Aliases. Here offset is index of aliased key */
   {"SERVERNAME",     DSNKEY_SERVER_INDEX,                   DSN_TYPE_STRING, 0, 1},
@@ -152,9 +155,15 @@ MADB_Dsn *MADB_DSN_Init(MADB_Dsn *Dsn2init)
     /* Should this go to MADB_DSN_SetDefaults? The problem is that only used in dialog till the moment, not sure if
      * Dsn->IsTcpIp= 1 is appropriate default in driver.
      */
+    /* MYSQL_OPT_SSL_VERIFY_SERVER_CERT is set by default in C/C 3.4 and in the 11.4 server.
+       Making it default here as well. 0xff(-1) is the "default true"
+       if app sets it 0 or 1 - driver will enforce it, if it doesn't - this "default true"
+       will only be used if any other encryption related parameters are set */
+    Dsn->SslVerify= DSN_DEFAULT_TRUE;
     Dsn->NullSchemaMeansCurrent= '\1';
     Dsn->PsCacheSize= 250;
     Dsn->PsCacheMaxKeyLen= 2112;
+    Dsn->ParamCallbacks= '\1';
   }
   return Dsn;
 }
@@ -175,7 +184,6 @@ void MADB_DSN_Free(MADB_Dsn *Dsn)
   MADB_FREE(Dsn->Catalog);
   MADB_FREE(Dsn->CharacterSet);
   MADB_FREE(Dsn->InitCommand);
-  MADB_FREE(Dsn->TraceFile);
   MADB_FREE(Dsn->Socket);
   MADB_FREE(Dsn->ConnCPluginsDir);
   MADB_FREE(Dsn->SslKey);
@@ -236,6 +244,7 @@ BOOL MADB_DsnSwitchDependents(MADB_Dsn *Dsn, unsigned int Changed)
       case DSN_TYPE_OPTION:
       case DSN_TYPE_BOOL:
       case DSN_TYPE_CBOXGROUP:
+      case DSN_TYPE_RBGROUP:
         {
           KeySet= *GET_FIELD_PTR(Dsn, &DsnKeys[Changed], my_bool);
         }
@@ -326,6 +335,12 @@ my_bool MADB_DsnStoreValue(MADB_Dsn *Dsn, unsigned int DsnKeyIdx, char *Value, m
       *GET_FIELD_PTR(Dsn, DsnKey, char)= IntValue;
     }
     break;
+  case DSN_TYPE_RBGROUP:
+  {
+    int dummy= atoi(Value);
+    /* Here are remains of code for RBGROUP added for revoked feature, and for real use some change would be needed here */
+    *GET_FIELD_PTR(Dsn, DsnKey, char)= dummy != 0 ? '\1' : '\0';
+  }
   case DSN_TYPE_INT:
     if (*GET_FIELD_PTR(Dsn, DsnKey, int) && OverWrite == FALSE)
       break;
@@ -463,6 +478,7 @@ my_bool MADB_SaveDSN(MADB_Dsn *Dsn)
         }
         break;
       case DSN_TYPE_CBOXGROUP:
+      case DSN_TYPE_RBGROUP:
         {
           _snprintf(Value, 32, "%hu", (short)*GET_FIELD_PTR(Dsn, &DsnKeys[i], char));
           ret= SQLWritePrivateProfileString(Dsn->DSNName, DsnKeys[i].DsnKey, Value, "ODBC.INI");
@@ -714,6 +730,7 @@ SQLULEN MADB_DsnToString(MADB_Dsn *Dsn, char *OutString, SQLULEN OutLength)
         }
         break;
       case DSN_TYPE_CBOXGROUP:
+      case DSN_TYPE_RBGROUP:
         if (*GET_FIELD_PTR(Dsn, &DsnKeys[i], char))
         {
           _snprintf(IntVal, sizeof(IntVal), "%hu", (short)*GET_FIELD_PTR(Dsn, &DsnKeys[i], char));
@@ -742,6 +759,4 @@ SQLULEN MADB_DsnToString(MADB_Dsn *Dsn, char *OutString, SQLULEN OutLength)
   }
   return TotalLength;
 }
-/* }}} */
-
-//} /* End of "extern C" */
+/* }}} */
\ No newline at end of file
