@@ -70,10 +70,10 @@ std::vector <std::vector<mariadb::bytes_view>> TypeInfoV3=
     sqllongvarchar},
   {XBV(CHAR),BV(XSTR(SQL_CHAR)),XBV(255),empty,empty,XBV(length),one,zero,three,zero,zero,zero,XBV(CHAR),zero,zero,zero,
     zero,ten, BV(XSTR(SQL_CHAR))},
-  {XBV(NUMERIC),BV(XSTR(SQL_NUMERIC)),XBV(65),empty,empty,BV("precision,scale"),one,zero,three,zero,zero,one,XBV(NUMERIC),XBV(-308),
-    XBV(308),zero,zero,ten, BV(XSTR(SQL_NUMERIC))},
-  {XBV(DECIMAL),BV(XSTR(SQL_DECIMAL)),XBV(65),empty,empty,BV("precision,scale"),one,zero,three,zero,zero,one,XBV(DECIMAL),XBV(-308),
-    XBV(308),zero,zero,ten, BV(XSTR(SQL_DECIMAL))},
+  {XBV(NUMERIC),BV(XSTR(SQL_NUMERIC)),BV(XSTR(MADB_DECIMAL_MAX_PRECISION)),empty,empty,BV("precision,scale"),one,zero,three,zero,
+    zero,one,XBV(NUMERIC),XBV(-308), XBV(308),zero,zero,ten, BV(XSTR(SQL_NUMERIC))},
+  {XBV(DECIMAL),BV(XSTR(SQL_DECIMAL)),BV(XSTR(MADB_DECIMAL_MAX_PRECISION)),empty,empty,BV("precision,scale"),one,zero,three,zero,
+    zero,one,XBV(DECIMAL),XBV(-308), XBV(308),zero,zero,ten, BV(XSTR(SQL_DECIMAL))},
   {XBV(INTEGER),BV(XSTR(SQL_INTEGER)),ten,empty,empty,Null,one,zero,three,BV(XSTR(SQL_FALSE)),zero,one,XBV(INTEGER),zero,zero,zero,
     zero,ten,BV(XSTR(SQL_INTEGER))},
   {XBV(INTEGER UNSIGNED),BV(XSTR(SQL_INTEGER)),ten,empty,empty,Null,one,zero,three,one,zero,one,XBV(INTEGER UNSIGNED),zero,zero,zero,
@@ -160,10 +160,10 @@ std::vector<std::vector<mariadb::bytes_view>> TypeInfoV2=
     sqllongvarchar},
   {XBV(CHAR),BV(XSTR(SQL_CHAR)),XBV(255),empty,empty,XBV(length),one,zero,three,zero,zero,zero,XBV(CHAR),zero,zero,zero,zero,ten,
     BV(XSTR(SQL_CHAR))},
-  {XBV(NUMERIC),BV(XSTR(SQL_NUMERIC)),XBV(65),empty,empty,BV("precision,scale"),one,zero,three,zero,zero,one,XBV(NUMERIC),XBV(-308),XBV(308),zero,
-    zero,ten, BV(XSTR(SQL_NUMERIC))},
-  {XBV(DECIMAL),BV(XSTR(SQL_DECIMAL)),XBV(65),empty,empty,BV("precision,scale"),one,zero,three,zero,zero,one,XBV(DECIMAL),XBV(-308),XBV(308),zero,
-    zero,ten, BV(XSTR(SQL_DECIMAL))},
+  {XBV(NUMERIC),BV(XSTR(SQL_NUMERIC)),BV(XSTR(MADB_DECIMAL_MAX_PRECISION)),empty,empty,BV("precision,scale"),one,zero,three,zero,zero,one,
+    XBV(NUMERIC),XBV(-308),XBV(308),zero, zero,ten, BV(XSTR(SQL_NUMERIC))},
+  {XBV(DECIMAL),BV(XSTR(SQL_DECIMAL)),BV(XSTR(MADB_DECIMAL_MAX_PRECISION)),empty,empty,BV("precision,scale"),one,zero,three,zero,zero,one,
+    XBV(DECIMAL),XBV(-308),XBV(308),zero, zero,ten, BV(XSTR(SQL_DECIMAL))},
   {XBV(INTEGER),BV(XSTR(SQL_INTEGER)),ten,empty,empty,Null,one,zero,three,BV(XSTR(SQL_FALSE)),zero,one,XBV(INTEGER),zero,zero,zero,zero,ten,
     BV(XSTR(SQL_INTEGER))},
   {XBV(INTEGER UNSIGNED),BV(XSTR(SQL_INTEGER)),ten,empty,empty,Null,one,zero,three,one,zero,one,XBV(INTEGER UNSIGNED),zero,zero,zero,zero,ten,
